Method: Etcd.client

Defined in:
lib/etcd.rb

.client(opts = {}) ⇒ Object

Create and return a Etcd::Client object. It takes a hash opts as an argument which gets passed to the Etcd::Client.new method directly If opts is not passed default options are used, defined by Etcd::Client.new



13
14
15
16
17
# File 'lib/etcd.rb', line 13

def self.client(opts = {})
  Etcd::Client.new(opts) do |config|
    yield config if block_given?
  end
end